<?php

namespace Drupal\Tests\twig_tools\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests Twig Tools convert filters.
 *
 * @group twig_tools
 */
class TwigConvertTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = ['twig_tools'];

  /**
   * @covers Drupal\twig_tools\TwigExtension\TwigConvert::booleanValue
   */
  public function testBoolean() {

    $template = "
      {%- for item in boolean_test -%}
        {{- (item|boolean) is same as (false) ? 'false' : 'true' -}}{{ ', ' }}
      {%- endfor -%}
    ";

    $expected_output = 'false, true, false, true, false, true, true, true, false, true, true, true, true, false, false, true, false, ';

    $context = [
      'boolean_test' => [
        0,
        42,
        0.0,
        4.2,
        '',
        'string',
        'true',
        'false',
        '0',
        '1',
        [1, 2],
        [0],
        [0, 0],
        [],
        FALSE,
        TRUE,
        NULL,
      ],
    ];

    /** @var \Drupal\Core\Template\TwigEnvironment $environment */
    $environment = \Drupal::service('twig');
    $output = (string) $environment->renderInline($template, $context);

    $this->assertSame($expected_output, $output);
  }

  /**
   * @covers Drupal\twig_tools\TwigExtension\TwigConvert::integerValue
   */
  public function testInteger() {

    $template = "
      {%- for item in integer_test -%}
        {{- item|integer -}}{{ ', ' }}
      {%- endfor -%}
    ";

    $expected_output = '42, 4, 42, 42, -42, 34, 42, 10000000000, 26, 42000000, 0, 1, 0, 1, 0, 0, 1, 0, 1, ';

    $context = [
      'integer_test' => [
        42,
        4.2,
        '42',
        '+42',
        '-42',
        042,
        '042',
        1e10,
        0x1A,
        42000000,
        [],
        ['foo', 'bar'],
        FALSE,
        TRUE,
        NULL,
        0,
        1,
        0.0,
        1.0,
      ],
    ];

    /** @var \Drupal\Core\Template\TwigEnvironment $environment */
    $environment = \Drupal::service('twig');
    $output = (string) $environment->renderInline($template, $context);

    $this->assertSame($expected_output, $output);
  }

  /**
   * @covers Drupal\twig_tools\TwigExtension\TwigConvert::stringValue
   */
  public function testString() {

    $template = "
      {%- for item in string_test -%}
        {{- item|string -}}{{ ', ' }}
      {%- endfor -%}
    ";

    $expected_output = "42, 4.2, 42, +42, -42, 34, 042, 10000000000, 26, 42000000, , 1, , 0, 1, 0, 1, ";

    $context = [
      'string_test' => [
        42,
        4.2,
        '42',
        '+42',
        '-42',
        042,
        '042',
        1e10,
        0x1A,
        42000000,
        FALSE,
        TRUE,
        NULL,
        0,
        1,
        0.0,
        1.0,
      ],
    ];

    /** @var \Drupal\Core\Template\TwigEnvironment $environment */
    $environment = \Drupal::service('twig');
    $output = (string) $environment->renderInline($template, $context);

    $this->assertSame($expected_output, $output);
  }

  /**
   * @covers Drupal\twig_tools\TwigExtension\TwigConvert::md5Value
   */
  public function testMd5() {

    $template = "
      {%- for item in md5_test -%}
        {{- item|md5 -}}{{ ', ' }}
      {%- endfor -%}
    ";

    $expected_output = 'a1d0c6e83f027327d8461063f4ac58a6, 8653d5c7898950016e5d019df6815626, deda8ddbf790f3682d5cf69d237bb0b2, 8dfcb89fd8620e3e7fb6a03a53f307dc, a1d0c6e83f027327d8461063f4ac58a6, 0cbc6611f5540bd0809a388dc95a615b, cfcd208495d565ef66e7dff9f98764da, cfcd208495d565ef66e7dff9f98764da, c4ca4238a0b923820dcc509a6f75849b, ';

    $context = [
      'md5_test' => [
        '42',
        '4.2',
        '+42',
        '-42',
        '42',
        'Test',
        '0',
        '0',
        '1',
      ],
    ];

    /** @var \Drupal\Core\Template\TwigEnvironment $environment */
    $environment = \Drupal::service('twig');
    $output = (string) $environment->renderInline($template, $context);

    $this->assertSame($expected_output, $output);
  }

}
